pub enum NextStep<'b, O, P: ReadPrecision> {
Send(Vec<u8>),
Recv(RecvStep<'b, P>),
Finished(Finished<'b, O, P>),
}Available on crate features
proxy-handshake or client-handshake only.Expand description
Next step to take in the handshake
Returned by Handshake::step.
Instructions from the handshake implementation. Caller should match on this and perform the requested action.
Variants
Send(Vec<u8>)
Caller should send this data to the peer
Recv(RecvStep<'b, P>)
Caller should read from the peer and call one of the received functions.
Finished(Finished<'b, O, P>)
The handshake is complete
The returned Finished can be used to obtain the handshake output.
The Handshake should not be used any more after this.