pub struct SocksClientHandshake {
request: SocksRequest,
state: State,
reply: Option<SocksReply>,
}Expand description
The client (initiator) side of a SOCKS handshake.
Create you have one of these with SocksClientHandshake::new(),
and then use Handshake::step to drive it.
Fields
request: SocksRequestThe request that we are currently trying to negotiate with the proxy.
state: StateOur current state in negotiating that request.
reply: Option<SocksReply>If present, the return message that we received from the proxy.
Implementations
Sourceimpl SocksClientHandshake
impl SocksClientHandshake
Sourcepub fn new(request: SocksRequest) -> Self
pub fn new(request: SocksRequest) -> Self
Construct a new SocksClientHandshake that will attempt to negotiate
with a peer using request.
Sourcepub fn into_reply(self) -> Option<SocksReply>
pub fn into_reply(self) -> Option<SocksReply>
Consume this handshake’s state; if it finished successfully,
return the SocksReply that we got from the proxy..
Sourcefn send_v4(&mut self) -> Result<ImplNextStep>
fn send_v4(&mut self) -> Result<ImplNextStep>
Send the client side of the socks 4 handshake.
Sourcefn handle_v4(&mut self, r: &mut Reader<'_>) -> Result<ImplNextStep>
fn handle_v4(&mut self, r: &mut Reader<'_>) -> Result<ImplNextStep>
Handle a SOCKSv4 response.
Sourcefn send_v5_initial(&mut self) -> Result<ImplNextStep>
fn send_v5_initial(&mut self) -> Result<ImplNextStep>
Send our initial socks5 message (which negotiates our authentication methods).
Sourcefn handle_v5_auth(&mut self, r: &mut Reader<'_>) -> Result<ImplNextStep>
fn handle_v5_auth(&mut self, r: &mut Reader<'_>) -> Result<ImplNextStep>
Try to handle a socks5 reply telling us what authentication method to use, and reply as appropriate.
Sourcefn generate_v5_username_auth(&self) -> Result<Vec<u8>>
fn generate_v5_username_auth(&self) -> Result<Vec<u8>>
Return a message to perform username/password authentication.
Sourcefn handle_v5_username_ack(&mut self, r: &mut Reader<'_>) -> Result<ImplNextStep>
fn handle_v5_username_ack(&mut self, r: &mut Reader<'_>) -> Result<ImplNextStep>
Try to handle a reply from the socks5 proxy to acknowledge our username/password authentication, and reply as appropriate.
Sourcefn generate_v5_command(&self) -> Result<Vec<u8>>
fn generate_v5_command(&self) -> Result<Vec<u8>>
Return a message to encode our final socks5 request.
(This can be done either in response getting an ACK for our authentication, or in response to being told that we don’t need to authenticate.)
Sourcefn handle_v5_final(&mut self, r: &mut Reader<'_>) -> Result<ImplNextStep>
fn handle_v5_final(&mut self, r: &mut Reader<'_>) -> Result<ImplNextStep>
Handle a final socks5 reply.