SocksCmd

Struct SocksCmd 

pub struct SocksCmd(u8);
Command from the socks client telling us what to do.

Tuple Fields

0: u8

Implementations

Source

impl SocksCmd

pub const CONNECT: SocksCmd

Connect to a remote TCP address:port.

pub const BIND: SocksCmd

Not supported in Tor.

pub const UDP_ASSOCIATE: SocksCmd

Not supported in Tor.

pub const RESOLVE: SocksCmd

Lookup a hostname, return an IP address. (Tor only.)

pub const RESOLVE_PTR: SocksCmd

Lookup an IP address, return a hostname. (Tor only.)

fn to_str(self) -> Option<&'static str>

pub fn is_recognized(self) -> bool

Return true if this value is one that we recognize.

pub fn from_name(name: &str) -> Option<Self>

Try to convert this value from one of the recognized names.

fn get(self) -> u8

Return the underlying integer that this value represents.

Source

impl SocksCmd

fn recognized(self) -> bool

Return true if this is a supported command.

fn requires_port(self) -> bool

Return true if this is a command for which we require a port.