pub struct SocksRequest {
version: SocksVersion,
cmd: SocksCmd,
addr: SocksAddr,
port: u16,
auth: SocksAuth,
}Expand description
A completed SOCKS request, as negotiated on a SOCKS connection.
Once this request is done, we know where to connect. Don’t discard this object immediately: Use it to report success or failure.
Fields
version: SocksVersionNegotiated SOCKS protocol version.
cmd: SocksCmdThe command requested by the SOCKS client.
addr: SocksAddrThe target address.
port: u16The target port.
auth: SocksAuthAuthentication information.
(Tor doesn’t believe in SOCKS authentication, since it cannot possibly secure. Instead, we use it for circuit isolation.)
Implementations
Sourceimpl SocksRequest
impl SocksRequest
Sourcepub fn reply(
&self,
status: SocksStatus,
addr: Option<&SocksAddr>,
) -> EncodeResult<Vec<u8>>
pub fn reply( &self, status: SocksStatus, addr: Option<&SocksAddr>, ) -> EncodeResult<Vec<u8>>
Format a reply to this request, indicating success or failure.
Note that an address should be provided only when the request was for a RESOLVE.
Sourcefn s4(
&self,
status: SocksStatus,
addr: Option<&SocksAddr>,
) -> EncodeResult<Vec<u8>>
fn s4( &self, status: SocksStatus, addr: Option<&SocksAddr>, ) -> EncodeResult<Vec<u8>>
Format a SOCKS4 reply.
Sourcefn s5(
&self,
status: SocksStatus,
addr: Option<&SocksAddr>,
) -> EncodeResult<Vec<u8>>
fn s5( &self, status: SocksStatus, addr: Option<&SocksAddr>, ) -> EncodeResult<Vec<u8>>
Format a SOCKS5 reply.
Sourceimpl SocksRequest
impl SocksRequest
Sourcepub fn new(
version: SocksVersion,
cmd: SocksCmd,
addr: SocksAddr,
port: u16,
auth: SocksAuth,
) -> Result<Self>
pub fn new( version: SocksVersion, cmd: SocksCmd, addr: SocksAddr, port: u16, auth: SocksAuth, ) -> Result<Self>
Create a SocksRequest with a given set of fields.
Return an error if the inputs aren’t supported or valid.
Sourcepub fn version(&self) -> SocksVersion
pub fn version(&self) -> SocksVersion
Return the negotiated version (4 or 5).