pub struct Finished<'b, O, P: ReadPrecision> { /* private fields */ }proxy-handshake or client-handshake only.Expand description
A completed handshake
Represents:
Handshake::Output, a value representing the meaning of the completed protocol exchange.- Possibly, some data which was received, but didn’t form part of the protocol.
Implementations
Sourceimpl<'b, O> Finished<'b, O, PreciseReads>
impl<'b, O> Finished<'b, O, PreciseReads>
Sourcepub fn into_output(self) -> Result<O, Bug>
pub fn into_output(self) -> Result<O, Bug>
Return (just) the output of the completed handshake
Available only if the Buffer was constructed with Buffer::new_precise()
(or equivalent).
Sourceimpl<'b, O, P: ReadPrecision> Finished<'b, O, P>
impl<'b, O, P: ReadPrecision> Finished<'b, O, P>
Sourcepub fn into_output_and_slice(self) -> (O, &'b [u8])
pub fn into_output_and_slice(self) -> (O, &'b [u8])
Return the output, and the following already-read data as a slice
(After calling this, the following already-read data
will no longer be in the Buffer.)
Sourcepub fn into_output_and_vec(self) -> (O, Vec<u8>)
pub fn into_output_and_vec(self) -> (O, Vec<u8>)
Return the output, and the following already-read data as a Vec
The Vec is quite likely to have a considerably larger capacity than contents.
(Its capacity is usually the original buffer size, when the Buffer was created.)
The Buffer should not be discarded after calling this;
it will not be usable.
Sourcepub fn into_output_forbid_pipelining(self) -> Result<O, Error>
pub fn into_output_forbid_pipelining(self) -> Result<O, Error>
Return the output of the completed handshake, declaring any readahead a protocol error
This function is appropriate when the peer is not supposed to send data
until the handshake is complete.
If data did arrive before then, and was read, we call it a protocol error,
Error::ForbiddenPipelining.