pub struct SocksCmd(/* private fields */);Expand description
Command from the socks client telling us what to do.
Implementations
Sourceimpl SocksCmd
impl SocksCmd
Sourcepub const UDP_ASSOCIATE: SocksCmd
pub const UDP_ASSOCIATE: SocksCmd
Not supported in Tor.
Sourcepub const RESOLVE_PTR: SocksCmd
pub const RESOLVE_PTR: SocksCmd
Lookup an IP address, return a hostname. (Tor only.)
Sourcepub fn is_recognized(self) -> bool
pub fn is_recognized(self) -> bool
Return true if this value is one that we recognize.