HasHandshakeOutput

Trait HasHandshakeOutput 

pub(super) trait HasHandshakeOutput<O> {
    // Required method
    fn take_output(&mut self) -> Option<O>;
}
Handshake structs whose output can be obtained

Derive this with #[derive_deftly(Handshake)].

Required Methods

fn take_output(&mut self) -> Option<O>

Obtain the output from a handshake completed with .handshake

Call only if Action said finished, and then only once. Otherwise, will return None.

Implementors