pub struct RecvStep<'b, P: ReadPrecision> { /* private fields */ }Available on crate features
proxy-handshake or client-handshake only.Expand description
Next step - details for reading from the peer
Value in NextStep::Recv.
Caller should read from the peer and call one of the received functions.
Specifically, caller should do one of the following:
-
Read some data into the slice returned by
.buf(), and then call.note_received(). -
Determine the available buffer space with
.buf().len(), write some data into the buffer’sunfilled_slice(), and callBuffer::note_received. This allows the caller to dispose of theRecvStep(which mutably borrows theBuffer) while reading, at the cost of slightly less correctness checking by the compiler.
The caller should not wait for enough data to fill the whole buf.
Implementations